==> gameap-3.1-shared.zip: upload/resources/lang/ru/games.php <==
<?php

return [
    'title_games_list'    => 'Список игр',
    'title_game'          => 'Игра',
    'title_game_mod'      => 'Мод',
    'title_add'           => 'Добавление игры',
    'title_add_mod'       => 'Добавление модификации',
    'title_edit'          => 'Редактирование игры',
    'title_edit_mod'      => 'Редактировать мод',
    
    'game'                => 'Игра',
    'games'               => 'Игры',
    
    'add'                 => 'Добавить игру',
    'add_mod'             => 'Добавить модификацию',
    'add_first_mod'       => 'Добавить первый мод',

    'upgrade'             => 'Обновить игры',
    
    'name'                => 'Имя',
    'code'                => 'Код',
    'engine'              => 'Движок',
    'mods'                => 'Моды',

    'run_commands'        => 'Команды',
    
    // GameMod edit page
    'main'                => 'Основное',
    'servers_commands'    => 'Команды',
    'vars'                => 'Переменные',
    'fast_rcon_commands'  => 'Fast RCON команды',
    
    'basic_info'          => 'Основное',
    'game_info'           => 'Параметры игры',
    'game_mod_info'       => 'Параметры игрового мода',
    'steam_info'          => 'Настройки steamcmd',
    'repositories'        => 'Репозитории',
    'repositories_local'  => 'Локальные репозитории',
    'repositories_remote' => 'Удаленные репозитории',
    
    // Descriptions
    'd_kick_cmd'          => 'Шорткоды: {id} -- id игрока, {name} -- имя игрока',
    'd_ban_cmd'           => 'Шорткоды: {id} -- id игрока, {name} -- имя игрока, {time} -- время, {reason} -- причина',
    'd_srestart_cmd'      => '',
    'd_chname_cmd'        => 'Шорткоды: {id} -- id игрока, {name} -- текущее имя игрока, {new_name} -- новый ник игрока, {reason} -- причина',
    'd_chmap_cmd'         => 'Шорткоды: {map}',
    'd_sendmsg_cmd'       => 'Шорткоды: {msg} -- сообщение',
    'd_passwd_cmd'        => 'Шорткоды: {password} -- пароль',

    'd_upgrade_confirm'   => 'Это действие обновит игры и моды. Некоторые изменённые вами данные могут быть перезаписаны. Продолжить?',
    
    'var'                 => 'Переменная',
    'default'             => 'По умолчанию',
    'info'                => 'Описание',
    'admin_var'           => 'Переменная администратора',
    
    'description'         => 'Описание',
    'rcon_command'        => 'RCON команда',

    'create_success_msg' => 'Игра успешно добавлена',
    'update_success_msg' => 'Игра успешно обновлена',
    'delete_success_msg' => 'Игра успешно удалена',

    'mod_create_success_msg' => 'Мод успешно добавлен',
    'mod_update_success_msg' => 'Мод успешно обновлён',
    'mod_delete_success_msg' => 'Мод успешно удалён',

    'upgrade_success_msg'    => 'Игры успешно обновлены',
    'upgrade_fail_msg'       => 'Ошибка обновления',
];

==> gameap-3.2-shared.zip: upload/resources/lang/ru/games.php <==
<?php

return [
    'title_games_list'    => 'Список игр',
    'title_game'          => 'Игра',
    'title_game_mod'      => 'Мод',
    'title_add'           => 'Добавление игры',
    'title_add_mod'       => 'Добавление модификации',
    'title_edit'          => 'Редактирование игры',
    'title_edit_mod'      => 'Редактировать мод',
    
    'game'                => 'Игра',
    'games'               => 'Игры',
    
    'add'                 => 'Добавить игру',
    'add_mod'             => 'Добавить модификацию',
    'add_first_mod'       => 'Добавить первый мод',

    'upgrade'             => 'Обновить игры',
    
    'name'                => 'Имя',
    'code'                => 'Код',
    'engine'              => 'Движок',
    'mods'                => 'Моды',

    'run_commands'        => 'Команды',
    
    // GameMod edit page
    'main'                => 'Основное',
    'servers_commands'    => 'Команды',
    'vars'                => 'Переменные',
    'fast_rcon_commands'  => 'Fast RCON команды',
    
    'basic_info'          => 'Основное',
    'game_info'           => 'Параметры игры',
    'game_mod_info'       => 'Параметры игрового мода',
    'steam_info'          => 'Настройки steamcmd',
    'repositories'        => 'Репозитории',
    'repositories_local'  => 'Локальные репозитории',
    'repositories_remote' => 'Удаленные репозитории',
    
    // Descriptions
    'd_kick_cmd'          => 'Шорткоды: {id} -- id игрока, {name} -- имя игрока',
    'd_ban_cmd'           => 'Шорткоды: {id} -- id игрока, {name} -- имя игрока, {time} -- время, {reason} -- причина',
    'd_srestart_cmd'      => '',
    'd_chname_cmd'        => 'Шорткоды: {id} -- id игрока, {name} -- текущее имя игрока, {new_name} -- новый ник игрока, {reason} -- причина',
    'd_chmap_cmd'         => 'Шорткоды: {map}',
    'd_sendmsg_cmd'       => 'Шорткоды: {msg} -- сообщение',
    'd_passwd_cmd'        => 'Шорткоды: {password} -- пароль',

    'd_upgrade_confirm'   => 'Это действие обновит игры и моды. Некоторые изменённые вами данные могут быть перезаписаны. Продолжить?',
    
    'var'                 => 'Переменная',
    'default'             => 'По умолчанию',
    'info'                => 'Описание',
    'admin_var'           => 'Переменная администратора',
    
    'description'         => 'Описание',
    'rcon_command'        => 'RCON команда',

    'create_success_msg' => 'Игра успешно добавлена',
    'update_success_msg' => 'Игра успешно обновлена',
    'delete_success_msg' => 'Игра успешно удалена',

    'mod_create_success_msg' => 'Мод успешно добавлен',
    'mod_update_success_msg' => 'Мод успешно обновлён',
    'mod_delete_success_msg' => 'Мод успешно удалён',

    'upgrade_success_msg'    => 'Игры успешно обновлены',
    'upgrade_fail_msg'       => 'Ошибка обновления',

    'delete_game_confirm_msg' => 'Вы уверены, что хотите удалить игру?',
    'delete_mod_confirm_msg'  => 'Вы уверены, что хотите удалить мод?',
];
